==> oce_0.17.1.orig.tar.gz: oce-OCE-0.17.1/src/BRepAlgoAPI/BRepAlgoAPI_Cut.cxx <==
// Created on: 1993-10-15
// Created by: Remi LEQUETTE
// Copyright (c) 1993-1999 Matra Datavision
// Copyright (c) 1999-2014 OPEN CASCADE SAS
//
// This file is part of Open CASCADE Technology software library.
//
// This library is free software; you can redistribute it and/or modify it under
// the terms of the GNU Lesser General Public License version 2.1 as published
// by the Free Software Foundation, with special exception defined in the file
// OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
// distribution for complete text of the license and disclaimer of any warranty.
//
// Alternatively, this file may be used under the terms of Open CASCADE
// commercial license or contractual agreement.

#include <BRepAlgoAPI_Cut.ixx>

#include <BRepAlgoAPI_BooleanOperation.hxx>

//=======================================================================
//function : BRepAlgoAPI_Cut
//purpose  : 
//=======================================================================
  BRepAlgoAPI_Cut::BRepAlgoAPI_Cut(const TopoDS_Shape& S1, 
                                   const TopoDS_Shape& S2)
: BRepAlgoAPI_BooleanOperation(S1, S2, BOPAlgo_CUT)
{
  BRepAlgoAPI_BooleanOperation* pBO=
    (BRepAlgoAPI_BooleanOperation*) (void*) this;
  pBO->Build();
}
//=======================================================================
//function : BRepAlgoAPI_Cut
//purpose  : 
//=======================================================================
  BRepAlgoAPI_Cut::BRepAlgoAPI_Cut(const TopoDS_Shape& S1, 
                                   const TopoDS_Shape& S2,
                                   const BOPAlgo_PaveFiller& aDSF,
                                   const Standard_Boolean bFWD)
: BRepAlgoAPI_BooleanOperation(S1, S2, aDSF, (bFWD) ? BOPAlgo_CUT : BOPAlgo_CUT21)
{
  BRepAlgoAPI_BooleanOperation* pBO=
    (BRepAlgoAPI_BooleanOperation*) (void*) this;
  pBO->Build();
}

==> oce_0.18.3.orig.tar.gz: oce-OCE-0.18.3/src/BRepAlgoAPI/BRepAlgoAPI_Cut.cxx <==
// Created on: 1993-10-15
// Created by: Remi LEQUETTE
// Copyright (c) 1993-1999 Matra Datavision
// Copyright (c) 1999-2014 OPEN CASCADE SAS
//
// This file is part of Open CASCADE Technology software library.
//
// This library is free software; you can redistribute it and/or modify it under
// the terms of the GNU Lesser General Public License version 2.1 as published
// by the Free Software Foundation, with special exception defined in the file
// OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
// distribution for complete text of the license and disclaimer of any warranty.
//
// Alternatively, this file may be used under the terms of Open CASCADE
// commercial license or contractual agreement.

#include <BRepAlgoAPI_Cut.ixx>

#include <BRepAlgoAPI_BooleanOperation.hxx>

//=======================================================================
//function : BRepAlgoAPI_Cut
//purpose  : 
//=======================================================================
BRepAlgoAPI_Cut::BRepAlgoAPI_Cut()
:
  BRepAlgoAPI_BooleanOperation()
{
  myOperation=BOPAlgo_CUT;
}
//=======================================================================
//function : BRepAlgoAPI_Cut
//purpose  : 
//=======================================================================
BRepAlgoAPI_Cut::BRepAlgoAPI_Cut(const BOPAlgo_PaveFiller& aPF)
:
  BRepAlgoAPI_BooleanOperation(aPF)
{
  myOperation=BOPAlgo_CUT;
}
//=======================================================================
//function : ~BRepAlgoAPI_Cut
//purpose  : 
//=======================================================================
BRepAlgoAPI_Cut::~BRepAlgoAPI_Cut()
{
}
//=======================================================================
//function : BRepAlgoAPI_Cut
//purpose  : 
//=======================================================================
BRepAlgoAPI_Cut::BRepAlgoAPI_Cut(const TopoDS_Shape& S1, 
                                 const TopoDS_Shape& S2)
:
  BRepAlgoAPI_BooleanOperation(S1, S2, BOPAlgo_CUT)
{
  BRepAlgoAPI_BooleanOperation* pBO=
    (BRepAlgoAPI_BooleanOperation*) (void*) this;
  pBO->Build();
}
//=======================================================================
//function : BRepAlgoAPI_Cut
//purpose  : 
//=======================================================================
BRepAlgoAPI_Cut::BRepAlgoAPI_Cut(const TopoDS_Shape& S1, 
                                 const TopoDS_Shape& S2,
                                 const BOPAlgo_PaveFiller& aDSF,
                                 const Standard_Boolean bFWD)
: 
  BRepAlgoAPI_BooleanOperation(S1, S2, aDSF, 
                               (bFWD) ? BOPAlgo_CUT : BOPAlgo_CUT21)
{
  BRepAlgoAPI_BooleanOperation* pBO=
    (BRepAlgoAPI_BooleanOperation*) (void*) this;
  pBO->Build();
}
